==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicComboBoxRenderer.h <==
// public class javax.swing.plaf.basic.BasicComboBoxRenderer

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class d7ef9fe7ff454b0d javax_swing_JLabel
// @dep_class 1fc8da7e7a16725c javax_swing_plaf_basic_BasicComboBoxRenderer

// header file dependencies
// @dep_header javax_swing_JLabel

#include "javax/swing/JLabel.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboBoxRenderer_H_
#define _JC_javax_swing_plaf_basic_BasicComboBoxRenderer_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_JList$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_refs	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$refs	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object;

typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$fields_struct	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vmethods	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtable	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtype	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$fields_struct {
	struct _jc_object	*noFocusBorder;
};
extern _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$fields_struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object *);

// Virtual methods
extern struct _jc_java_awt_Component$object *_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method$getListCellRendererComponent$f2ca6ffe042e46a2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object *, struct _jc_javax_swing_JList$object *, struct _jc_java_lang_Object$object *, jint, jboolean, jboolean);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method_info$getListCellRendererComponent$f2ca6ffe042e46a2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method_info$getPreferredSize$4730bc91c97b24d9;

// Static methods
extern void _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vmethods {
	struct _jc_java_awt_Component$object	*(*getListCellRendererComponent$f2ca6ffe042e46a2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object *, struct _jc_javax_swing_JList$object *, struct _jc_java_lang_Object$object *, jint, jboolean, jboolean);
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JLabel$vmethods	javax_swing_JLabel;
	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vmethods	javax_swing_plaf_basic_BasicComboBoxRenderer;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$refs {
    _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_refs	javax_swing_plaf_basic_BasicComboBoxRenderer;
    _jc_javax_swing_JLabel$sub_refs	javax_swing_JLabel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JLabel$sub_nonrefs	javax_swing_JLabel;
    _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_nonrefs	javax_swing_plaf_basic_BasicComboBoxRenderer;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object {
	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtype _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboBoxRenderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboBoxRenderer_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicComboBoxRenderer.h <==
// public class javax.swing.plaf.basic.BasicComboBoxRenderer

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class d7ef9fe7ff454b0d javax_swing_JLabel
// @dep_class 1fc8da7e7a16725c javax_swing_plaf_basic_BasicComboBoxRenderer

// header file dependencies
// @dep_header javax_swing_JLabel

#include "javax/swing/JLabel.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboBoxRenderer_H_
#define _JC_javax_swing_plaf_basic_BasicComboBoxRenderer_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_JList$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_refs	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$refs	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object;

typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$fields_struct	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vmethods	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtable	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtype	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$fields_struct {
	struct _jc_object	*noFocusBorder;
};
extern _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$fields_struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Component$object *_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method$getListCellRendererComponent$f2ca6ffe042e46a2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object *, struct _jc_javax_swing_JList$object *, struct _jc_java_lang_Object$object *, jint, jboolean, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method_info$getListCellRendererComponent$f2ca6ffe042e46a2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method_info$getPreferredSize$4730bc91c97b24d9;

// Static methods
extern void _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vmethods {
	struct _jc_java_awt_Component$object	*(*getListCellRendererComponent$f2ca6ffe042e46a2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object *, struct _jc_javax_swing_JList$object *, struct _jc_java_lang_Object$object *, jint, jboolean, jboolean) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JLabel$vmethods	javax_swing_JLabel;
	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vmethods	javax_swing_plaf_basic_BasicComboBoxRenderer;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$refs {
    _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_refs	javax_swing_plaf_basic_BasicComboBoxRenderer;
    _jc_javax_swing_JLabel$sub_refs	javax_swing_JLabel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JLabel$sub_nonrefs	javax_swing_JLabel;
    _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$sub_nonrefs	javax_swing_plaf_basic_BasicComboBoxRenderer;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$object {
	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboBoxRenderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$vtype _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboBoxRenderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboBoxRenderer$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboBoxRenderer_H_ */
